# DRF Dog

![Tests](https://github.com/coaxsoft/drf_dog/workflows/Tests/badge.svg)

Copy-paste utilities for Django REST Framework.

---

**Documentation** [https://coaxsoft.github.io/drf_dog](https://coaxsoft.github.io/drf_dog)

**Source code** [https://github.com/coaxsoft/drf_dog](https://github.com/coaxsoft/drf_dog)

---

Why copy-paste utilities? Often, it is mentally hard to install
no name packages, especially, to commercial project, but it is easy to copy-paste
the solution from stack overflow or github. 

For this reason, we try to keep this project the way that it
can be easily installed from `PyPi` or just copy-pasted to your own code.

## Requirements

-  Python 3.6+
-  Django 3.0+
-  Django REST Framework 3.11+

## Installation

Install using ``pip``


```bash
$ pip install drf_dog
```

## License

This project is licensed under the terms of the ISC License